paulicirc.layers
================

.. automodule:: paulicirc.layers

Layer
-----

.. autoclass:: paulicirc.layers.Layer
    :show-inheritance:
    :members:
    :special-members: __new__

LayeredCircuit
--------------

.. autoclass:: paulicirc.layers.LayeredCircuit
    :show-inheritance:
    :members:

PAULI_CHARS
-----------

.. autodata:: paulicirc.layers.PAULI_CHARS
